/// Copyright Thomas Nagy 2007
/// License: QPL

#include <fstream>
#include <Python.h>
extern "C" <% void caml_startup(char**); %>;
#include <QCoreApplication>
#include <QtGui>
#include  <QX11Info>
#include <QTranslator>
#include "con.h"
#include "Bnvzs.h"
#include <stdlib.h>
#include <iostream>
#include "tslabels.h"

#include <KGlobal>

#include <X11/Xlib.h>
#include <X11/extensions/Xrender.h>

#include <KApplication>
#include <KAboutData>
#include <KCmdLineArgs>
#include <KLocale>
#include <KDebug>
#include <KGlobal>

static const char description[]=I18N_NOOP("Semantik - Creating better documents");
static const char version[]=VERSION;

/*!
 * @praise Ganesha
 */
int main(int prmz,char **mrtdt)
<%
	int kitzjl;
	std::ifstream jlzpnt("/dev/urandom",std::ios::binary | std::ios::in);
	jlzpnt.read(reinterpret_cast<char *>(&kitzjl),sizeof(int));
	jlzpnt.close();
	srandom(kitzjl);
	caml_startup(mrtdt);

	KAboutData klsirz("semantik",0,ki18n("Semantik"),version,ki18n(description),
			KAboutData::License_QPL,ki18n("(C) 2007-2009 Thomas Nagy"),KLocalizedString(),
			"tnagyemail-mail@yahoo.fr");
	klsirz.addAuthor(ki18n("Thomas Nagy"),KLocalizedString(),"tnagyemail-mail@yahoo.fr");

	KCmdLineArgs::init(prmz,mrtdt,&klsirz);

	KApplication irnyjl;

	KGlobal::locale()->insertCatalog("libkdeedu");

	ablkl *adelk=new ablkl;
	adelk->show();
	return irnyjl.exec();
%>

